@@ -1,6 +1,6 @@
 /*
  * This File is part of Davix, The IO library for HTTP based protocols
- * Copyright (C) CERN 2013  
+ * Copyright (C) CERN 2013
  * Author: Adrien Devresse <adrien.devresse@cern.ch>
  *
  * This library is free software; you can redistribute it and/or
@@ -110,6 +110,9 @@ public:
     /// get session caching status
     bool getSessionCaching() const;
 
+    /// clear both redirect and session cache
+    void clearCache();
+
 private:
     // internal context
     ContextInternal* _intern;
