@@ -1,6 +1,6 @@
 /*
  * This File is part of Davix, The IO library for HTTP based protocols
- * Copyright (C) CERN 2013  
+ * Copyright (C) CERN 2013
  * Author: Adrien Devresse <adrien.devresse@cern.ch>
  *
  * This library is free software; you can redistribute it and/or
@@ -25,6 +25,7 @@
 #include "httpiovec.hpp"
 #include "davix_reliability_ops.hpp"
 #include "iobuffmap.hpp"
+#include "AzureIO.hpp"
 
 namespace Davix{
 
@@ -41,7 +42,7 @@ HttpIOChain& ChainFactory::instanceChain(const CreationFlags & flags, HttpIOChai
         elem = elem->add(new HttpIOBuffer());
     }
 
-    elem->add(new HttpIO())->add(new HttpIOVecOps());
+    elem->add(new AzureIO())->add(new HttpIO())->add(new HttpIOVecOps());
     return c;
 }
 
