@@ -1,6 +1,6 @@
 /*
  * This File is part of Davix, The IO library for HTTP based protocols
- * Copyright (C) CERN 2013  
+ * Copyright (C) CERN 2013
  * Author: Adrien Devresse <adrien.devresse@cern.ch>
  *
  * This library is free software; you can redistribute it and/or
@@ -44,16 +44,17 @@ using namespace StrUtil;
 
 namespace Davix{
 
-static const std::string simple_listing("<propfind xmlns=\"DAV:\"><prop><resourcetype><collection/></resourcetype></prop></propfind>");
-
 static const std::string stat_listing("<?xml version=\"1.0\" encoding=\"utf-8\" ?><D:propfind xmlns:D=\"DAV:\" xmlns:L=\"LCGDM:\"><D:prop>"
-                                      "<D:displayname/><D:getlastmodified/><D:creationdate/><D:getcontentlength/>"
+                                      "<D:displayname/><D:getlastmodified/><D:creationdate/><D:getcontentlength/><D:quota-used-bytes/>"
                                       "<D:resourcetype><D:collection/></D:resourcetype><L:mode/>"
                                       "<D:owner></D:owner><D:group></D:group>"
                                       "</D:prop>"
                                       "</D:propfind>");
 
-
+static const std::string quota_stat("<?xml version=\"1.0\" encoding=\"utf-8\" ?><D:propfind xmlns:D=\"DAV:\" xmlns:L=\"LCGDM:\"><D:prop>"
+                                      "<D:quota-used-bytes/><D:quota-available-bytes/>"
+                                      "</D:prop>"
+                                      "</D:propfind>");
 
 struct DirHandle{
 
@@ -179,6 +180,46 @@ dav_ssize_t getStatInfo(Context & c, const Uri & url, const RequestParams * p,
     return ret;
 }
 
+QuotaInfo::QuotaInfo() : d_ptr(new Internal()) { }
+QuotaInfo::~QuotaInfo() { }
+dav_size_t QuotaInfo::getUsedBytes() {
+    return d_ptr->used_bytes;
+}
+dav_size_t QuotaInfo::getFreeSpace() {
+    return d_ptr->free_space;
+}
+
+class QuotaInfoHandler {
+public:
+    static void setdptr(QuotaInfo &info, QuotaInfo::Internal &internal) {
+        info.d_ptr.reset(new QuotaInfo::Internal(internal));
+    }
+};
+
+void getQuotaInfo(Context & c, const Uri & url, const RequestParams *p, QuotaInfo &info) {
+    DavixError * tmp_err = NULL;
+    HttpRequest req(c, url, &tmp_err);
+    checkDavixError(&tmp_err);
+
+    req.setParameters(*p);
+    req.addHeaderField("Depth","0");
+    req.setRequestMethod("PROPFIND");
+    req.setRequestBody(quota_stat);
+
+    if(req.executeRequest(&tmp_err) == 0 && !tmp_err) {
+        DavPropXMLParser parser;
+        parser.parseChunk(&(req.getAnswerContentVec()[0]), req.getAnswerContentVec().size());
+        std::deque<FileProperties> & props = parser.getProperties();
+        if( props.size() < 1){
+            throw DavixException(davix_scope_stat_str(), Davix::StatusCode::WebDavPropertiesParsingError, "Parsing Error : properties number < 1");
+        }else{
+            QuotaInfoHandler::setdptr(info, props.front().quota);
+        }
+    }
+
+    checkDavixError(&tmp_err);
+}
+
 void parse_creation_deletion_result(int code, const Uri & u, const std::string & scope, const std::vector<char> & body){
     switch(code){
         case 200:
@@ -462,6 +503,11 @@ StatInfo & HttpMetaOps::statInfo(IOChainContext & iocontext, StatInfo &st_info){
     return st_info;
 }
 
+QuotaInfo & HttpMetaOps::quotaInfo(IOChainContext & iocontext, QuotaInfo &info) {
+    getQuotaInfo(iocontext._context, iocontext._uri, iocontext._reqparams, info);
+    return info;
+}
+
 bool HttpMetaOps::nextSubItem(IOChainContext &iocontext, std::string &entry_name, StatInfo &info){
     return webdav_directory_listing(directoryItem, iocontext._context, iocontext._reqparams, iocontext._uri, stat_listing,
                              entry_name, info);
@@ -584,7 +630,7 @@ void S3MetaOps::makeCollection(IOChainContext &iocontext){
 void s3StatMapper(Context& context, const RequestParams* params, const Uri & uri, struct StatInfo& st_info){
     const std::string scope = "Davix::s3StatMapper";
     DavixError * tmp_err=NULL;
-    HeadRequest req(context, uri, &tmp_err);    
+    HeadRequest req(context, uri, &tmp_err);
 
     // we need to modify it, hence copy
     RequestParams p(params);
@@ -620,16 +666,16 @@ void s3StatMapper(Context& context, const RequestParams* params, const Uri & uri
 
             size_t prop_size = 0;
             do{ // first entry
-               TRY_DAVIX{ 
+               TRY_DAVIX{
                     s_resu = incremental_listdir_parsing(&http_req, &parser, 2048, scope);
                }CATCH_DAVIX(&tmp_err)
-                
+
                if(tmp_err && (tmp_err->getStatus() == StatusCode::IsNotADirectory)){
                   std::ostringstream ss;
                   ss << uri << " not found";
                   throw DavixException(scope, StatusCode::FileNotFound, ss.str());
                 }
-               
+
                prop_size = parser.getProperties().size();
                if(s_resu < 2048 && prop_size <1){ // verify request status : if req done + no data -> error
                   throw DavixException(scope, StatusCode::ParsingError, "Invalid server response, not a S3 listing");
