@@ -1,6 +1,6 @@
 /*
  * This File is part of Davix, The IO library for HTTP based protocols
- * Copyright (C) CERN 2013  
+ * Copyright (C) CERN 2013
  * Author: Adrien Devresse <adrien.devresse@cern.ch>
  *
  * This library is free software; you can redistribute it and/or
@@ -55,6 +55,9 @@ public:
     // get statInfo
     virtual StatInfo & statInfo(IOChainContext & iocontext, StatInfo & st_info);
 
+    // get quota info
+    virtual QuotaInfo & quotaInfo(IOChainContext & iocontext, QuotaInfo &info);
+
     virtual bool nextSubItem(IOChainContext &iocontext, std::string &entry_name, StatInfo &info);
 
 private:
