@@ -1,6 +1,6 @@
 /*
  * This File is part of Davix, The IO library for HTTP based protocols
- * Copyright (C) CERN 2013  
+ * Copyright (C) CERN 2013
  * Author: Adrien Devresse <adrien.devresse@cern.ch>
  *
  * This library is free software; you can redistribute it and/or
@@ -113,7 +113,7 @@ protected:
     advise_t _last_advise;
 
     // locker
-    boost::recursive_mutex _rwlock;
+    std::recursive_mutex _rwlock;
     // write cache
     Ptr::Scoped<IOBufferLocalFile> _local;
 
