@@ -428,7 +428,7 @@ int NEONRequest::negotiateRequest(DavixError** err){
                 return startRequest(err);
             }
 
-            if( status == NE_CONNECT &&  requestCleanup() ){
+            if( (status == NE_CONNECT || status == NE_LOOKUP) &&  requestCleanup() ){
                 DAVIX_SLOG(DAVIX_LOG_VERBOSE, DAVIX_LOG_HTTP, "Impossible to connect to {}, retry from origin {}", _current->getString(), _orig->getString());
                 _number_try++;
                 return startRequest(err);
@@ -743,7 +743,8 @@ dav_ssize_t NEONRequest::readToFd(int fd, dav_size_t read_size, DavixError** err
            }while(write_len >0);
     }
 
-    return (ret>= 0)?total:ret;
+    if(total > 0) return total;
+    return ret;
 }
 
 
