@@ -167,7 +167,7 @@ private:
 
 
     ne_request * _req;
-    boost::shared_ptr<Uri>  _current, _orig;
+    std::shared_ptr<Uri>  _current, _orig;
     // req info
     int _number_try;
     // number of redirects so far
@@ -200,6 +200,10 @@ private:
     int _last_request_flag;
 
     std::vector< std::pair<std::string, std::string > > _headers_field;
+    int _accepted_202_retries;
+
+    bool _early_termination;
+    DavixError* _early_termination_error;
 
     ////////////////////////////////////////////
     // Private Members
