@@ -1,6 +1,6 @@
 /*
  * This File is part of Davix, The IO library for HTTP based protocols
- * Copyright (C) CERN 2013  
+ * Copyright (C) CERN 2013
  * Author: Adrien Devresse <adrien.devresse@cern.ch>
  *
  * This library is free software; you can redistribute it and/or
@@ -21,6 +21,7 @@
 
 #include <string>
 #include <algorithm>
+#include <mutex>
 #include <davix_internal.hpp>
 #include "neonsessionfactory.hpp"
 
@@ -28,7 +29,7 @@
 
 namespace Davix {
 
-static boost::once_flag neon_once = BOOST_ONCE_INIT;
+static std::once_flag neon_once;
 
 static void init_neon(){
     ne_sock_init();
@@ -50,13 +51,13 @@ NEONSessionFactory::NEONSessionFactory() :
     _redir_caching(!redirCachingDisabled()),
     _redirCache(256)
 {
-    boost::call_once(&init_neon, neon_once);
+    std::call_once(neon_once, &init_neon);
     DAVIX_SLOG(DAVIX_LOG_TRACE, DAVIX_LOG_CORE, "HTTP/SSL Session caching {}", (_session_caching?"ENABLED":"DISABLED"));
     DAVIX_SLOG(DAVIX_LOG_TRACE, DAVIX_LOG_CORE, "Redirection Session caching {}", (_redir_caching?"ENABLED":"DISABLED"));
 }
 
 NEONSessionFactory::~NEONSessionFactory(){
-    boost::lock_guard<boost::mutex> lock(_sess_mut);
+    std::lock_guard<std::mutex> lock(_sess_mut);
     for(std::multimap<std::string, ne_session*>::iterator it = _sess_map.begin(); it != _sess_map.end(); ++it){
         ne_session_destroy(it->second);
     }
@@ -128,7 +129,7 @@ ne_session* NEONSessionFactory::create_recycled_session(const RequestParams & pa
 
     if(params.getKeepAlive()){
         ne_session* se= NULL;
-        boost::lock_guard<boost::mutex> lock(_sess_mut);
+        std::lock_guard<std::mutex> lock(_sess_mut);
         std::multimap<std::string, ne_session*>::iterator it;
         if( (it = _sess_map.find(create_map_keys_from_URL(protocol, host, port))) != _sess_map.end()){
             DAVIX_SLOG(DAVIX_LOG_DEBUG, DAVIX_LOG_HTTP, "cached ne_session found ! taken from cache ");
@@ -150,7 +151,7 @@ void NEONSessionFactory::internal_release_session_handle(ne_session* sess){
     // clear sensitive data
     // none
     //
-    boost::lock_guard<boost::mutex> lock(_sess_mut);
+    std::lock_guard<std::mutex> lock(_sess_mut);
     std::multimap<std::string, ne_session*>::iterator it;
     std::string sess_key;
     sess_key.append(ne_get_scheme(sess)).append(ne_get_server_hostport(sess));
@@ -169,30 +170,30 @@ static const std::pair<std::string, std::string> redirectionCreateKey(const std:
     return std::make_pair(origin.getString(), mymethod);
 }
 
-void NEONSessionFactory::addRedirection( const std::string & method, const Uri & origin, boost::shared_ptr<Uri> dest){
+void NEONSessionFactory::addRedirection( const std::string & method, const Uri & origin, std::shared_ptr<Uri> dest){
     if(_redir_caching){
         DAVIX_SLOG(DAVIX_LOG_DEBUG, DAVIX_LOG_HTTP, "Add cached redirection <{} {} {}>", method.c_str(), origin.getString().c_str(), dest->getString().c_str());
         _redirCache.insert(redirectionCreateKey(method, origin), dest);
     }
 }
 
-boost::shared_ptr<Uri> NEONSessionFactory::redirectionResolve(const std::string & method, const Uri & origin){
-    boost::shared_ptr<Uri> res = redirectionResolveSingle(method, origin);
+std::shared_ptr<Uri> NEONSessionFactory::redirectionResolve(const std::string & method, const Uri & origin){
+    std::shared_ptr<Uri> res = redirectionResolveSingle(method, origin);
     if(res.get() != NULL){
-        boost::shared_ptr<Uri> res_rec = redirectionResolve(method, *res);
+        std::shared_ptr<Uri> res_rec = redirectionResolve(method, *res);
         if(res_rec.get() != NULL)
             return res_rec;
     }
     return res;
 }
 
-boost::shared_ptr<Uri> NEONSessionFactory::redirectionResolveSingleIntern(const std::string & method, const Uri & origin){
+std::shared_ptr<Uri> NEONSessionFactory::redirectionResolveSingleIntern(const std::string & method, const Uri & origin){
     return  _redirCache.find(redirectionCreateKey(method, origin));
 }
 
 
-boost::shared_ptr<Uri> NEONSessionFactory::redirectionResolveSingle(const std::string & method, const Uri & origin){
-    boost::shared_ptr<Uri> res = redirectionResolveSingleIntern(method, origin);
+std::shared_ptr<Uri> NEONSessionFactory::redirectionResolveSingle(const std::string & method, const Uri & origin){
+    std::shared_ptr<Uri> res = redirectionResolveSingleIntern(method, origin);
     if(res.get() != NULL){
         DAVIX_SLOG(DAVIX_LOG_DEBUG, DAVIX_LOG_HTTP, "Found redirection  <{} {} {}>", method.c_str(), origin.getString().c_str(), res->getString().c_str());
     }
@@ -200,7 +201,7 @@ boost::shared_ptr<Uri> NEONSessionFactory::redirectionResolveSingle(const std::s
 }
 
 void NEONSessionFactory::redirectionClean(const std::string & method, const Uri & origin){
-    boost::shared_ptr<Uri> res = redirectionResolveSingleIntern(method, origin);
+    std::shared_ptr<Uri> res = redirectionResolveSingleIntern(method, origin);
     if(res.get() != NULL){
         DAVIX_SLOG(DAVIX_LOG_DEBUG, DAVIX_LOG_HTTP, "Delete Cached redirection for <{} {} {}>", method.c_str(), origin.getString().c_str(), res->getString().c_str());
         _redirCache.erase(redirectionCreateKey(method, origin));
